Crate torii_auth_passkey

Crate torii_auth_passkey 

A passkey authentication plugin for Torii.

This plugin provides passkey (WebAuthn) authentication capabilities to Torii applications. It allows users to register and authenticate using passkeys (biometric authentication, security keys, etc).

Warning

This plugin is meant to be used as part of the Torii authentication framework and should not be instantiated directly. Use Torii’s plugin system to add passkey authentication to your application.

Features

  • Passkey registration
  • Passkey authentication
  • Challenge-response based authentication flow

Structs

ChallengeId
Unique identifier for a passkey challenge
PasskeyCredentialCreationOptions
Public-facing credential creation options for registering a new passkey
PasskeyCredentialRequestOptions
Public-facing credential request options for authenticating with a passkey
PasskeyLoginCompletion
Client response to complete a passkey login
PasskeyLoginRequest
A request to authenticate with a passkey
PasskeyPlugin
A plugin for managing passkey authentication.
PasskeyRegistrationCompletion
Client response to complete a passkey registration
PasskeyRegistrationRequest
A request to register a new passkey

Enums

PasskeyError
PasskeyErrorContext
Context for error messages to provide better diagnostics

Traits

PasskeyAuthPlugin
Trait defining passkey authentication functionality