A passkey authentication plugin for Torii.
This plugin provides passkey (WebAuthn) authentication capabilities to Torii applications. It allows users to register and authenticate using passkeys (biometric authentication, security keys, etc).
Warning
This plugin is meant to be used as part of the Torii authentication framework and should not be instantiated directly. Use Torii’s plugin system to add passkey authentication to your application.
Features
- Passkey registration
- Passkey authentication
- Challenge-response based authentication flow
Structs
- Challenge
Id - Unique identifier for a passkey challenge
- Passkey
Credential Creation Options - Public-facing credential creation options for registering a new passkey
- Passkey
Credential Request Options - Public-facing credential request options for authenticating with a passkey
- Passkey
Login Completion - Client response to complete a passkey login
- Passkey
Login Request - A request to authenticate with a passkey
- Passkey
Plugin - A plugin for managing passkey authentication.
- Passkey
Registration Completion - Client response to complete a passkey registration
- Passkey
Registration Request - A request to register a new passkey
Enums
- Passkey
Error - Passkey
Error Context - Context for error messages to provide better diagnostics
Traits
- Passkey
Auth Plugin - Trait defining passkey authentication functionality